<h1 align="center">

[![pypi](https://img.shields.io/pypi/v/cb_key_stroke.svg)](https://pypi.org/project/cb_key_stroke/)
[![python](https://img.shields.io/pypi/pyversions/cb_key_stroke.svg)](https://pypi.org/project/cb_key_stroke/)


</h1>
# README - Welcome to Chriesibaum's Key Stroke Module


**cb_key_stroke** is the python key stroke module for all platforms that captures any key in a running loop. It can be
used to e.g. easily interrupt a running loop by pressing a user defined key or key combination.
It comes with a simple and intuitive API and can be used on Linux, Mac as well Windows Systems.

## Installation
For a simple and painless installation of the cb-key-stroke module in your system, please refer to the documentation. You will find what you are looking for under the heading "Installation of the cb-key-stroke module".

## Documentation

For API documentation, usage and examples see files in the "sphinx" directory. The ".rst" files can be read in any text editor or being converted to HTML or PDF using Sphinx. An HTML version is online at https://chriesibaum.github.io/cb_key_stroke/


## How to build the Package
- To build the packet, simply run ``make build`` and enjoy a café.

- To give the documentation a new shine, simply run ``make doc``.


## Build Requirements
For details see: https://packaging.python.org/en/latest/tutorials/packaging-projects/
- python3
- and a ton of packages specified in the settings (pyproject.toml)
  to install all and everything run
  ```. envsetup.sh / envsetup.bat```
  to create a virtual environment.
